!$Id: amber_SciCal.prg,v 1.4 2009/10/20 12:43:51 agabasch Exp $
!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!COPYRIGHT (c) 2004 European Southern Observatory
!LICENSE
!
!PROJECT:   VLT Data Flow System
!AUTHOR:    T.Licha/R.Palsa/I.Percheron - ESO/DMD/DPG
!SUBSYSTEM: AMBER Instrument Pipeline
!PURPOSE:   MIDAS interface procedure for AMBER pipeline recipe.
!
!$Name: amber-4_2_2 $
!$Revision: 1.4 $
!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

set/midas keyw=10000,10000

define/local recipeName/c/1/20 "amber_SciCal"

define/local resultFrames/c/1/150 "{P1}"
define/local inputFrames/c/1/150 "{P2}"
define/local calibData/c/1/150 "{P3}"
define/local recipeSpecs/c/1/150 " {recipeName} {recipeName}.sof"

define/local didPath/c/1/200 " -I"
define/local didList/c/1/200 " -D"
define/local pafList/c/1/100000 " -p qc*.paf"

define/local proPrefixOption/c/1/20 " --output-prefix="
define/local logFileOption/c/1/20 " --log-file="
define/local recDirOption/c/1/20 " --recipe-dir="

define/local recDir/c/1/60 "$PIPE_HOME/amber"
define/local proDir/c/1/60 ""
define/local proPrefix/c/1/60 ""
define/local logFile/c/1/60 ""

define/local cmdLine/c/1/400 " " all
define/local line/c/1/400 " " all

define/local pos/i/1/1 0

define/local fid/i/1/2 0 all
define/local sid/i/1/2 0 all


log/rec {recipeName} IN

! delete tmp products
$$rm -f /tmp/amber_*


pos = m$indexb(resultFrames, "/") - 1

proDir = resultFrames(1:{pos})
pos = pos + 2
proPrefix = resultFrames({pos}:)
logFile = proPrefix // ".log"

!-------------------------------------------------------
! The following piece of code is a TEMPORARY PATCH
! to get the RAW and CALIB tags into the set of frames
! file. It has to stay there until the RBS has been
! patched and will be removed afterwards
!-------------------------------------------------------
open/file {recipeName}.sof write sid
if sid(1) .lt. 0 then
    return 1
endif

open/file {inputFrames} read fid
if fid(1) .lt. 0 then
    return 1
endif

raw_loop:
    read/file {fid(1)} line
    if fid(2) .gt. 0 then
        fid(2) = fid(2) + 1
        line({fid(2)}:) = " RAW"
        write/file {sid(1)},key line
        goto raw_loop
    endif
close/file {fid(1)}

if calibData .ne. "?" then
    open/file {calibData} read fid
    if fid(1) .lt. 0 then
        return 1
    endif

cal_loop:
    read/file {fid(1)} line
    if fid(2) .gt. 0 then
        fid(2) = fid(2) + 1
        line({fid(2)}:) = " CALIB"
        write/file {sid(1)},key line
        goto cal_loop
    endif

    close/file {fid(1)}
endif
close/file {sid(1)}


!cmdLine = "$CPLDIR/bin/esorex --output-dir=" // proDir -
!          // proPrefixOption // proPrefix -
!          // recDirOption // recDir -
!          // logFileOption // logFile // recipeSpecs
!write/out exec {cmdLine}

$echo "esorex --suppress-prefix=FALSE --output-dir={proDir}"  "\\\\" >  esorex_cmd_file
$echo {proPrefixOption}{proPrefix}    "\\\\" >> esorex_cmd_file
$echo {recDirOption}{recDir}     "\\\\" >> esorex_cmd_file
$echo {logFileOption}{logFile}        "\\\\" >> esorex_cmd_file
$echo {recipeSpecs}                          >> esorex_cmd_file

$chmod +x esorex_cmd_file
cmdLine = "esorex_cmd_file"



outputi = m$system(cmdLine)
if outputi(1) .ne. 0 then
  return 1
endif

if m$exist("qc0000.paf") .eq. 1 then
  didPath(5:) = m$symbol("INS_ROOT") // "/SYSTEM/Dictionary"

  didList(5:) = "PRO" 

  cmdLine = "QC1LogWriter -s AMBER" // didPath // didList // pafList

  outputi = m$system(cmdLine)
!  if outputi(1) .ne. 0 then
!    return 1
!  endif
endif

! Log end of reduction
log/rec {recipeName} OUT


!-------------------------------------------------------
! The following piece of code is a plotting the results
! of the data reduction
!-------------------------------------------------------
define cnt/I/1/1  0
define/local amdlibcall/C/1024/1 ""

define/local stindex/I/1/1 1

define/local ntel/I/1/1   0 
define/local objectobs/C/1/30   ""
define/local dateobs/C/1/30 ""
define/local outfile/C/1/128 ""

define/local wavchan/I/1/1  0
define/local snrchan/I/1/1  0
define/local chan/I/1/1     0

modify/graph parent


do cnt = 0 99 
WRITE/OUT "Searching temporary Product /tmp/amber_{cnt}.fits"

ECHO/OFF

INDISK/MFITS /tmp/amber_{cnt}.fits result-amber 

write/keyword ntel/I/1/1   {result-amber0000,ESO.DET.NTEL} 
write/keyword objectobs/C/1/30   {result-amber0000,ESO.OBS.NAME}
!write/keyword objectobs/C/1/30   {result-amber0000,ESO.OBS.TARG.NAME}
write/keyword dateobs/C/1/30   {result-amber0000,ESO.OBS.START}
write/keyword insmode/C/1/30   {result-amber0000,ESO.OCS.OBS.SPECCONF}
!write/keyword catgobs/C/1/30   {result-amber0000,ESO.DPR.CATG}


write/keyword sta1/I/1/1   {result-amber0000,ESO.QC.STA1} 
write/keyword sta2/I/1/1   {result-amber0000,ESO.QC.STA2}


! 1 Postscriptfile for each product
write/keyword outfile/C/1/128 " /tmp/amber_{cnt}.ps"

! clean old ps files
$$rm -f amber_*.ps

!-------------------------------------------------------------------------------------------------
IF NTEL .EQ. 2 THEN 



! Plot the first baseline then overplot the other baselines
write/out "Plot Piston for the Baseline data"
! the plot will also be saved as postscript.ps
! first graph lower left : piston=f(SNR)
compute/table  result-amber0006.tbl  :PISTON_OPD = :PISTON_OPD*1e-3
copy/tt result-amber0006.tbl :FRINGE_CONTRAST_SNR result-amber0006.tbl :FRINGE_SNR
copy/tt result-amber0006.tbl :PISTON_OPD result-amber0005.tbl :PISTON_OPD
statistics/table result-amber0006.tbl :FRINGE_SNR
write/keyword Minimumsnr/r/1/1 {OUTPUTR(1)}
write/keyword Maximumsnr/r/1/1 {OUTPUTR(2)}
statistics/table result-amber0006.tbl :PISTON_OPD
write/keyword Minimumpist/r/1/1 {OUTPUTR(1)}
write/keyword Maximumpist/r/1/1 {OUTPUTR(2)}
statistics/table result-amber0006.tbl :TIME
write/keyword Minimumtime/r/1/1 {OUTPUTR(1)}
write/keyword Maximumtime/r/1/1 {OUTPUTR(2)}
select/tabl result-amber0006.tbl :FRINGE_SNR.GE.2.0
write/keyword snrmore2/i/1/1 {OUTPUTI(1)}
select/tabl result-amber0006.tbl ALL
select/tabl result-amber0006.tbl :FRINGE_SNR.LT.2.0
write/keyword snrless2/i/1/1 {OUTPUTI(1)}
select/tabl result-amber0006.tbl ALL

! the following (commented out is to create one independant small graph on the big graph
set/graph pmode=0 font=1 stype=5 ssize=.5 ltype=0 colour=1
plot/axes {Minimumsnr(1)},{Maximumsnr(1)} {Minimumpist(1)},{Maximumpist(1)} -55,-40,20,15 "Fringe_SNR" "Piston (mm)"
overplot/table result-amber0006.tbl :FRINGE_SNR :PISTON_OPD
! new plot
set/graph pmode=0 font=1 stype=5 ssize=.5 ltype=0 colour=1
overplot/axes {Minimumtime(1)},{Maximumtime(1)} {Minimumpist(1)},{Maximumpist(1)} -55,-40,85,15 "time (s)" "Piston (mm)"
overplot/table result-amber0006.tbl :TIME :PISTON_OPD
!reselect everything
select/tabl result-amber0006.tbl ALL
set/graph pmode=0 font=1 stype=5 ssize=.5 ltype=0 colour=1
SET/GRAP colour=1
!LABEL/GRAPHIC "Plotting all Frames" 30,180,mm 0 1 0
LABEL/GRAPHIC "{dateobs}" 180,185,mm 0 1.5 0
LABEL/GRAPHIC "{objectobs}" 180,180,mm 0 1.5 0
LABEL/GRAPHIC "{insmode}" 180,175,mm 0 1.5 0
!LABEL/GRAPHIC "{catgobs}" 40,175,mm 0 1.5 0


! copy the colum SNR in the same table than the VIS2data
copy/tt result-amber0006.tbl :FRINGE_CONTRAST_SNR result-amber0005.tbl :FRINGE_SNR
                                                                                                                                          
! Averaging visibility over time and plotting
$$rm -f vis2ghk*.bdf  vis2arr.bdf vis2aver.*
COPY/TEIM    result-amber0005.tbl :VIS2DATA P6=vis2ghk

WRITE/KEYWORD wavchan/I/1/1  {vis2ghk0001.bdf,NPIX(1)}
WRITE/KEYWORD snrchan/I/1/1  {result-amber0005.tbl,TBLCONTR(4)}
WRITE/KEYWORD chan/I/1/1     0

create/image vis2arr 2,{wavchan},{snrchan} 1,1,1,1
write/out    "Creating visibility-wavelength array..."
do chan = 1 {snrchan}
   insert/image vis2ghk{chan} vis2arr @1,@{chan}
enddo
average/col  vis2aver = vis2arr
copy/it      vis2aver.bdf vis2aver.tbl
copy/tt      vis2aver.tbl #1  result-amber0005.tbl   :VIS2AVER
$$rm -f vis2ghk*.bdf  vis2arr.bdf vis2aver.*
!select the VIS2AVER which will not be displayed on the graph [-0.2,1.2] to display the number
statistics/table result-amber0005.tbl :VIS2AVER
write/keyword Minimumv2aver/r/1/1 {OUTPUTR(1)}
write/keyword Maximumv2aver/r/1/1 {OUTPUTR(2)}
select/tabl result-amber0005.tbl :VIS2AVER.LT.-0.2
write/keyword smallVis2aver/i/1/1 {OUTPUTI(1)} 
select/tabl result-amber0005.tbl :VIS2AVER.GT.1.2
write/keyword BigVis2aver/i/1/1 {OUTPUTI(1)} 
select/tabl result-amber0005.tbl ALL 
select/tabl result-amber0005.tbl :VIS2AVER.GE.-0.2.AND.:VIS2AVER.LE.1.2
write/keyword plottedVis2aver/i/1/1 {OUTPUTI(1)} 
select/tabl result-amber0005.tbl ALL 
write/keyword AllVis2aver/i/1/1 {OUTPUTI(1)} 
set/graph pmode=0 font=1 stype=5 ssize=.5 ltype=0 colour=1
overplot/axes {Minimumpist(1)},{Maximumpist(1)} {Minimumv2aver(1)},{Maximumv2aver(1)} -55,-40,85,68 "Piston (mm)" 
overplot/table result-amber0005.tbl :PISTON_OPD :VIS2AVER
! Plot the visibilities=f(Piston)
set/graph pmode=0 font=1 stype=5 ssize=.5 ltype=0 colour=1
overplot/axes {Minimumpist(1)},{Maximumpist(1)} -0.2,1.2,.2,.1 -55,-40,15,68 "Piston (mm)" "Visibility (^2)"
overplot/table result-amber0005.tbl :PISTON_OPD :VIS2AVER

! Plot the Visibilities on the same graph, plot V1 then overplot + create a postscript.ps
write/out "Plot VISIBILITY for the Baseline data"
! second graph, vis2=f(snr) higher left
set/graph  pmode=0 font=1 stype=5 ssize=.5 ltype=0 colour=1
overplot/axes {Minimumsnr(1)},{Maximumsnr(1)} {Minimumv2aver(1)},{Maximumv2aver(1)} -55,-40,85,120 "Fringe_SNR"
overplot/table result-amber0005.tbl :FRINGE_SNR :VIS2AVER
overplot/axes {Minimumsnr(1)},{Maximumsnr(1)} -0.2,1.2,.2,.1 -55,-40,15,120 "Fringe_SNR" "Visibility (^2)"
overplot/table result-amber0005.tbl :FRINGE_SNR :VIS2AVER
label/graph  "Total number of frames: {AllVis2aver}"  70,180,mm 0 1.5 0 
label/graph  "Vis^2<-0.2: {smallVis2aver} - plotted {plottedVis2aver} - Vis^2>1.2: {BigVis2aver}"  70,176,mm 0 1.5 0
label/graph  "snr<2 {snrless2} - snr>=2 {snrmore2}"  70,172,mm 0 1.5 0
SET/GRAP colour=1
! Averaging VIS2DATA over time and plotting
   write/out   "Averaging VIS2 for baseline 1"
   select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta1}
   $$rm -f vis2lamghk*.bdf mycat.cat avevis2lam.bdf avevis2lam.tbl
   copy/teim           result-amber0005.tbl :VIS2DATA P6=vis2lamghk
   create/icat         mycat.cat vis2lamghk*.bdf
   average/images      avevis2lam = mycat.cat
   copy/it             avevis2lam.bdf avevis2lam.tbl
   copy/tt             avevis2lam  #1  result-amber0003.tbl  :VIS2LAM
   $$rm -f vis2lamghk*.bdf mycat.cat avevis2lam.bdf avevis2lam.tbl
                                                                                                                                          
! lambda is given in m, get the plot in microns
compute/table  result-amber0003.tbl  :WAVE = :EFF_WAVE*1e6
name/column    result-amber0003.tbl  :WAVE  F8.3 "microns"
!get the min and max to plot the 3 Visibilities on the same plot
write/out "get the max of the Visibility"
do stindex = 1 1
statistics/table result-amber0003.tbl :VIS2LAM
enddo
select/tabl result-amber0003.tbl :VIS2LAM.LT.-0.2
write/keyword smallVis2lam/i/1/1 {OUTPUTI(1)}
select/tabl result-amber0003.tbl :VIS2LAM.GT.1.2
write/keyword BigVis2lam/i/1/1 {OUTPUTI(1)}
select/tabl result-amber0003.tbl ALL
write/keyword AllVis2lam/i/1/1 {OUTPUTI(1)}
compute/table result-amber0003.tbl :MAX_COL = MAX(:VIS2LAM)
compute/table result-amber0003.tbl :MIN_COL = MIN(:VIS2LAM)
statistics/table result-amber0003.tbl :MAX_COL
write/keyword Maximumvis2/r/1/1 {OUTPUTR(2)}
statistics/table result-amber0003.tbl :MIN_COL
write/keyword Minimumvis2/r/1/1 {OUTPUTR(1)}
write/out "read the stats on the table"
statistics/table result-amber0003.tbl :WAVE
write/keyword Maximumlam/r/1/1 {OUTPUTR(2)}
write/keyword Minimumlam/r/1/1 {OUTPUTR(1)}
                                                                                                                                          
                                                                                                                                          
! plot the data on the same plot + create postscript.ps
   write/out   "Plot averaged Visibility for baseline data"
   set/graph pmode=0 font=1 stype=0 ltype=1 colour=1
   overplot/axes {Minimumlam(1)},{Maximumlam(1)} {Minimumvis2(1)},{Maximumvis2(1)} -45,-40,225,30 "Wavelength"
   overplot/table result-amber0003.tbl :WAVE :VIS2LAM

   set/graph pmode=0 font=1 stype=0 ltype=1 colour=1
   overplot/axes {Minimumlam(1)},{Maximumlam(1)} -0.2,1.2,.2,.1 -45,-40,165,30 "Wavelength" "Visibility (^2)"
   overplot/table result-amber0003.tbl :WAVE :VIS2LAM_0001



!
!
! Averaging spectrum over time and plotting
   write/out   "Averaging spectrum for baseline"
   select/tabl result-amber0006.tbl :STA_INDEX.EQ.{sta1}
   $$rm -f imghk*.bdf mycat.cat avespec.bdf avespec.tbl
   copy/teim           result-amber0006.tbl :FLUX_PI_MORE_PJ P6=imghk
   create/icat         mycat.cat imghk*.bdf
   average/images      avespec = mycat.cat
   copy/it             avespec.bdf avespec.tbl
   copy/tt             avespec  #1  result-amber0003.tbl  :SPEC
   $$rm -f imghk*.bdf mycat.cat avespec.bdf avespec.tbl
!get the min and max to plot the 2 spectra on the same plot
write/out "get the max of the spectra"
statistics/table result-amber0003.tbl :SPEC
compute/table result-amber0003.tbl :MAX_COL = MAX(:SPEC)
compute/table result-amber0003.tbl :MIN_COL = MIN(:SPEC)
statistics/table result-amber0003.tbl :MAX_COL
write/keyword Maximumflux/r/1/1 {OUTPUTR(2)}
statistics/table result-amber0003.tbl :MIN_COL
write/keyword Minimumflux/r/1/1 {OUTPUTR(1)}
write/out "read the stats on the table"
                                                                                                                                          
! plot the data on the same plot + create postscript.ps
   write/out   "Plot spectrum for baseline data"
   set/graph pmode=0 font=1 stype=0 ltype=1 colour=1
overplot/axes {Minimumlam(1)},{Maximumlam(1)} {Minimumflux(1)},{Maximumflux(1)},2000,500  -110,-45,160,90 "Wavelength" "Flux count"
SET/GRAP colour=1 ltype=1
   overplot/table result-amber0003.tbl :WAVE :SPEC
                                                                                                                                          
! copy to name according the product number
copy/graph POSTSCRIPT
cmdLine = "cp postscript.ps" // outfile
outputi = m$system(cmdLine)
!$$cp postscript.ps /tmp/amber_gasgano_plot.ps                                                                                                                                          
!enddo

!-------------------------------------------------------------------------
ELSE

write/keyword sta3/I/1/1   {result-amber0000,ESO.QC.STA3}

! Plot the first baseline then overplot the other baselines
write/out "Plot Piston for the Baseline data"
! the plot will also be saved as postscript.ps
! first graph lower left : piston=f(SNR)
compute/table  result-amber0007.tbl  :PISTON_OPD = :PISTON_OPD*1e-3
copy/tt result-amber0007.tbl :FRINGE_CONTRAST_SNR result-amber0007.tbl :FRINGE_SNR
copy/tt result-amber0007.tbl :PISTON_OPD result-amber0005.tbl :PISTON_OPD
statistics/table result-amber0007.tbl :FRINGE_SNR
write/keyword Minimumsnr/r/1/1 {OUTPUTR(1)}
write/keyword Maximumsnr/r/1/1 {OUTPUTR(2)}
statistics/table result-amber0007.tbl :PISTON_OPD
write/keyword Minimumpist/r/1/1 {OUTPUTR(1)}
write/keyword Maximumpist/r/1/1 {OUTPUTR(2)}
statistics/table result-amber0007.tbl :TIME
write/keyword Minimumtime/r/1/1 {OUTPUTR(1)}
write/keyword Maximumtime/r/1/1 {OUTPUTR(2)}
select/tabl result-amber0007.tbl :STA_INDEX.EQ.{sta1}.AND.:FRINGE_SNR.GE.2.0
write/keyword snrmore2bas1/i/1/1 {OUTPUTI(1)}
select/tabl result-amber0007.tbl ALL
select/tabl result-amber0007.tbl :STA_INDEX.EQ.{sta2}.AND.:FRINGE_SNR.GE.2.0
write/keyword snrmore2bas2/i/1/1 {OUTPUTI(1)}
select/tabl result-amber0007.tbl ALL
select/tabl result-amber0007.tbl :STA_INDEX.EQ.{sta3}.AND.:FRINGE_SNR.GE.2.0
write/keyword snrmore2bas3/i/1/1 {OUTPUTI(1)}
select/tabl result-amber0007.tbl ALL
select/tabl result-amber0007.tbl :FRINGE_SNR.GE.2.0
write/keyword snrmore2/i/1/1 {OUTPUTI(1)}
select/tabl result-amber0007.tbl ALL
select/tabl result-amber0007.tbl :FRINGE_SNR.LT.2.0
write/keyword snrless2/i/1/1 {OUTPUTI(1)}
select/tabl result-amber0007.tbl ALL
select/tabl result-amber0007.tbl :STA_INDEX.EQ.{sta1}
! the following (commented out is to create one independant small graph on the big graph
set/graph pmode=0 font=1 stype=5 ssize=.3 ltype=0 colour=1
plot/axes {Minimumsnr(1)},{Maximumsnr(1)} {Minimumpist(1)},{Maximumpist(1)} -55,-40,20,15 "Fringe_SNR" "Piston"
overplot/table result-amber0007.tbl :FRINGE_SNR :PISTON_OPD

write/keyword stindex/I/1/1 2
select/tabl result-amber0007.tbl ALL
write/out "Plot Piston for the Baseline {stindex} data"
set/graph stype={stindex} ssize=.3 colour={stindex}
select/tabl result-amber0007.tbl :STA_INDEX.EQ.{sta2}
overplot/table result-amber0007.tbl :FRINGE_SNR :PISTON_OPD

write/keyword stindex/I/1/1 3
select/tabl result-amber0007.tbl ALL
write/out "Plot Piston for the Baseline {stindex} data"
set/graph stype={stindex} ssize=.3 colour={stindex}
select/tabl result-amber0007.tbl :STA_INDEX.EQ.{sta3}
overplot/table result-amber0007.tbl :FRINGE_SNR :PISTON_OPD

! new plot
select/tabl result-amber0007.tbl ALL
select/tabl result-amber0007.tbl :STA_INDEX.EQ.{sta1}
set/graph pmode=0 font=1 stype=5 ssize=.3 ltype=0 colour=1
overplot/axes {Minimumtime(1)},{Maximumtime(1)} {Minimumpist(1)},{Maximumpist(1)} -55,-40,85,15 "time (s)" "Piston (mm)"
overplot/table result-amber0007.tbl :TIME :PISTON_OPD

write/keyword stindex/I/1/1 2
write/out "Plot Piston for the Baseline {stindex} data"
select/tabl result-amber0007.tbl ALL
set/graph stype={stindex} ssize=.3 colour={stindex}
select/tabl result-amber0007.tbl :STA_INDEX.EQ.{sta2}
overplot/table result-amber0007.tbl :TIME :PISTON_OPD

write/keyword stindex/I/1/1 3
write/out "Plot Piston for the Baseline {stindex} data"
select/tabl result-amber0007.tbl ALL
set/graph stype={stindex} ssize=.3 colour={stindex}
select/tabl result-amber0007.tbl :STA_INDEX.EQ.{sta3}
overplot/table result-amber0007.tbl :TIME :PISTON_OPD


set/graph pmode=0 font=1 stype=5 ssize=.3 ltype=0 colour=1

SET/GRAP colour=1
LABEL/GRAPHIC "{dateobs}" 180,185,mm 0 1.5 0
LABEL/GRAPHIC "{objectobs}" 180,180,mm 0 1.5 0
LABEL/GRAPHIC "{insmode}" 180,175,mm 0 1.5 0
!LABEL/GRAPHIC "{catgobs}" 40,175,mm 0 1.5 0
   
!reselect everything
select/tabl result-amber0007.tbl ALL
                                                                                                                                          
! copy the colum SNR in the same table than the VIS2data
copy/tt result-amber0007.tbl :FRINGE_CONTRAST_SNR result-amber0005.tbl :FRINGE_SNR
                                                                                                                                          
! Averaging visibility over time and plotting
$$rm -f vis2ghk*.bdf  vis2arr.bdf vis2aver.*
COPY/TEIM    result-amber0005.tbl :VIS2DATA P6=vis2ghk
write/keyword wavchan/I/1/1  {vis2ghk0001.bdf,NPIX(1)}
write/keyword snrchan/I/1/1  {result-amber0005.tbl,TBLCONTR(4)}
write/keyword chan/I/1/1     0
create/image vis2arr 2,{wavchan},{snrchan} 1,1,1,1
write/out    "Creating visibility-wavelength array..."
do chan = 1 {snrchan}
   insert/image vis2ghk{chan} vis2arr @1,@{chan}
enddo
average/col  vis2aver = vis2arr
copy/it      vis2aver.bdf vis2aver.tbl
copy/tt      vis2aver.tbl #1  result-amber0005.tbl   :VIS2AVER
statistics/table result-amber0005.tbl :VIS2AVER
write/keyword Minimumv2aver/r/1/1 {OUTPUTR(1)}
write/keyword Maximumv2aver/r/1/1 {OUTPUTR(2)}
$$rm -f vis2ghk*.bdf  vis2arr.bdf vis2aver.*
!select the VIS2AVER which will not be displayed on the graph [-0.2,1.2] to display the number
select/tabl result-amber0005.tbl :VIS2AVER.LT.-0.2
write/keyword smallVis2aver/i/1/1 {OUTPUTI(1)}
select/tabl result-amber0005.tbl :VIS2AVER.GT.1.2
write/keyword BigVis2aver/i/1/1 {OUTPUTI(1)}
select/tabl result-amber0005.tbl ALL 
select/tabl result-amber0005.tbl :VIS2AVER.GE.-0.2.AND.:VIS2AVER.LE.1.2
write/keyword plottedVis2aver/i/1/1 {OUTPUTI(1)} 
select/tabl result-amber0005.tbl ALL
write/keyword AllVis2aver/i/1/1 {OUTPUTI(1)}
! Plot the visibilities=f(Piston)
set/graph pmode=0 font=1 stype=5 ssize=.3 ltype=0 colour=1
   select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta1}
overplot/axes {Minimumpist(1)},{Maximumpist(1)} {Minimumv2aver(1)},{Maximumv2aver(1)} -55,-40,90,68 "Piston (mm)" 
overplot/table result-amber0005.tbl :PISTON_OPD :VIS2AVER

write/keyword stindex/I/1/1 2
select/tabl result-amber0005.tbl ALL
set/graph stype={stindex} ssize=.3 colour={stindex}
select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta2}
overplot/table result-amber0005.tbl :PISTON_OPD :VIS2AVER

write/keyword stindex/I/1/1 3
select/tabl result-amber0005.tbl ALL
set/graph stype={stindex} ssize=.3 colour={stindex}
select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta3}
overplot/table result-amber0005.tbl :PISTON_OPD :VIS2AVER


select/tabl result-amber0005.tbl ALL
! Plot the visibilities=f(Piston)
set/graph pmode=0 font=1 stype=5 ssize=.3 ltype=0 colour=1
   select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta1}
overplot/axes {Minimumpist(1)},{Maximumpist(1)} -0.2,1.2,.2,.1 -55,-40,15,68 "Piston (mm)" "Visibility (^2)"
overplot/table result-amber0005.tbl :PISTON_OPD :VIS2AVER

write/keyword stindex/I/1/1 2
select/tabl result-amber0005.tbl ALL
set/graph stype={stindex} ssize=.3 colour={stindex}
select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta2}
overplot/table result-amber0005.tbl :PISTON_OPD :VIS2AVER

write/keyword stindex/I/1/1 3
select/tabl result-amber0005.tbl ALL
set/graph stype={stindex} ssize=.3 colour={stindex}
select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta3}
overplot/table result-amber0005.tbl :PISTON_OPD :VIS2AVER


select/tabl result-amber0005.tbl ALL
! Plot the Visibilities on the same graph, plot V1 then overplot + create a postscript.ps
   write/out "Plot VISIBILITY for the Baseline data"
! second graph, vis2=f(snr) higher left
                                                                                                                                          
set/graph  pmode=0 font=1 stype=5 ssize=.3 ltype=0 colour=1
   select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta1}
overplot/axes {Minimumsnr(1)},{Maximumsnr(1)} {Minimumv2aver(1)},{Maximumv2aver(1)} -55,-40,90,120 "Fringe_SNR" 
   overplot/table result-amber0005.tbl :FRINGE_SNR :VIS2AVER

   
write/keyword stindex/I/1/1 2
set/graph stype={stindex} ssize=.3 colour={stindex}
select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta2}
overplot/table result-amber0005.tbl :FRINGE_SNR :VIS2AVER

write/keyword stindex/I/1/1 3
set/graph stype={stindex} ssize=.3 colour={stindex}
select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta3}
overplot/table result-amber0005.tbl :FRINGE_SNR :VIS2AVER



set/graph  pmode=0 font=1 stype=5 ssize=.3 ltype=0 colour=1
   select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta1}
!overplot/axes {Minimumsnr(1)},{Maximumsnr(1)} -0.2,1.2,.2,.1 -115,-40,17,120 "Fringe_SNR" "Visibility (^2)"
overplot/axes {Minimumsnr(1)},{Maximumsnr(1)} -0.2,1.2,.2,.1 -55,-40,15,120 "Fringe_SNR" "Visibility (^2)"
   overplot/table result-amber0005.tbl :FRINGE_SNR :VIS2AVER

   
write/keyword stindex/I/1/1 2
set/graph stype={stindex} ssize=.3 colour={stindex}
select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta2}
overplot/table result-amber0005.tbl :FRINGE_SNR :VIS2AVER

write/keyword stindex/I/1/1 3
set/graph stype={stindex} ssize=.3 colour={stindex}
select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta3}
overplot/table result-amber0005.tbl :FRINGE_SNR :VIS2AVER


set/graph  colour=1

!LABEL/GRAPHIC "Plotting all Frames" 30,180,mm 0 1 0

label/graph  "Total number of frames: {AllVis2aver}"  70,185,mm 0 1.5 0 
label/graph  "Vis^2<-0.2: {smallVis2aver} - plotted {plottedVis2aver} - Vis^2>1.2: {BigVis2aver}"  70,181,mm 0 1.5 0
label/graph  "snr<2 {snrless2} - snr>=2: {snrmore2} B1: {snrmore2bas1} - B2: {snrmore2bas2} - B3: {snrmore2bas3}"  70,176,mm 0 1.5 0
!write the legend of the 2 plots

SET/GRAP colour=1
overplot/symb 5 90,163,mm 0.5
OVERPLOT/LINE 1 95,163,mm 105,163,mm
SET/GRAP colour=1
label/graph  "Baseline 1"  120,163,mm ? 1 .8
SET/GRAP colour=2
overplot/symb 2 90,166,mm 0.5
OVERPLOT/LINE 2 95,166,mm 105,166,mm
SET/GRAP colour=2
label/graph  "Baseline 2"  120,166,mm ? 1 .8
SET/GRAP colour=3
overplot/symb 3 90,169,mm 0.5
OVERPLOT/LINE 3 95,169,mm 105,169,mm
SET/GRAP colour=3
label/graph  "Baseline 3"  120,169,mm ? 1 .8
! Averaging VIS2DATA over time and plotting

write/keyword stindex/I/1/1 1
write/out   "Averaging VIS2 for baseline {stindex}"
select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta1}
$$rm -f vis2lamghk*.bdf mycat.cat avevis2lam.bdf avevis2lam.tbl
copy/teim           result-amber0005.tbl :VIS2DATA P6=vis2lamghk
create/icat         mycat.cat vis2lamghk*.bdf
average/images      avevis2lam = mycat.cat
copy/it             avevis2lam.bdf avevis2lam.tbl
copy/tt             avevis2lam  #1  result-amber0003.tbl  :VIS2LAM_{stindex}
$$rm -f vis2lamghk*.bdf mycat.cat avevis2lam.bdf avevis2lam.tbl

write/keyword stindex/I/1/1 2
write/out   "Averaging VIS2 for baseline {stindex}"
select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta2}
$$rm -f vis2lamghk*.bdf mycat.cat avevis2lam.bdf avevis2lam.tbl
copy/teim           result-amber0005.tbl :VIS2DATA P6=vis2lamghk
create/icat         mycat.cat vis2lamghk*.bdf
average/images      avevis2lam = mycat.cat
copy/it             avevis2lam.bdf avevis2lam.tbl
copy/tt             avevis2lam  #1  result-amber0003.tbl  :VIS2LAM_{stindex}
$$rm -f vis2lamghk*.bdf mycat.cat avevis2lam.bdf avevis2lam.tbl

write/keyword stindex/I/1/1 3
write/out   "Averaging VIS2 for baseline {stindex}"
select/tabl result-amber0005.tbl :STA_INDEX.EQ.{sta3}
$$rm -f vis2lamghk*.bdf mycat.cat avevis2lam.bdf avevis2lam.tbl
copy/teim           result-amber0005.tbl :VIS2DATA P6=vis2lamghk
create/icat         mycat.cat vis2lamghk*.bdf
average/images      avevis2lam = mycat.cat
copy/it             avevis2lam.bdf avevis2lam.tbl
copy/tt             avevis2lam  #1  result-amber0003.tbl  :VIS2LAM_{stindex}
$$rm -f vis2lamghk*.bdf mycat.cat avevis2lam.bdf avevis2lam.tbl

                                                                                                                                          
! lambda is given in m, get the plot in microns
compute/table  result-amber0003.tbl  :WAVE = :EFF_WAVE*1e6
name/column    result-amber0003.tbl  :WAVE  F8.3 "microns"
!get the min and max to plot the 3 Visibilities on the same plot
write/out "get the max of the Visibility"

do stindex = 1 3
statistics/table result-amber0003.tbl :VIS2LAM_{stindex}
enddo

compute/table result-amber0003.tbl :MAX_1 = MAX(:VIS2LAM_0001,:VIS2LAM_0002)
compute/table result-amber0003.tbl :MIN_1 = MIN(:VIS2LAM_0001,:VIS2LAM_0002)
statistics/table result-amber0003.tbl :MAX_1
statistics/table result-amber0003.tbl :MIN_1
compute/table result-amber0003.tbl :MAX_COL = MAX(:MAX_1,:VIS2LAM_0003)
compute/table result-amber0003.tbl :MIN_COL = MIN(:MIN_1,:VIS2LAM_0003)
statistics/table result-amber0003.tbl :MAX_COL
write/keyword Maximumvis2/r/1/1 {OUTPUTR(2)}
statistics/table result-amber0003.tbl :MIN_COL
write/keyword Minimumvis2/r/1/1 {OUTPUTR(1)}
write/out "read the stats on the table"
statistics/table result-amber0003.tbl :WAVE
write/keyword Maximumlam/r/1/1 {OUTPUTR(2)}
write/keyword Minimumlam/r/1/1 {OUTPUTR(1)}
                                                                                                                                          
                                                                                                                                          
! plot the data on the same plot + create postscript.ps
   write/out   "Plot averaged Visibility for baseline data"
   set/graph pmode=0 font=1 stype=0 ltype=1 colour=1
   overplot/axes {Minimumlam(1)},{Maximumlam(1)} {Minimumvis2(1)},{Maximumvis2(1)} -45,-40,225,30 "Wavelength" 
SET/GRAP colour=1 ltype=1
   overplot/table result-amber0003.tbl :WAVE :VIS2LAM_0001

   
do stindex = 2 3
SET/GRAP colour={stindex} ltype={stindex}
   overplot/table result-amber0003.tbl :WAVE :VIS2LAM_{stindex}
enddo
   set/graph pmode=0 font=1 stype=0 ltype=1 colour=1
   overplot/axes {Minimumlam(1)},{Maximumlam(1)} -0.2,1.2,.2,.1 -45,-40,165,30 "Wavelength" "Visibility (^2)"
SET/GRAP colour=1 ltype=1
   overplot/table result-amber0003.tbl :WAVE :VIS2LAM_0001
do stindex = 2 3
SET/GRAP colour={stindex} ltype={stindex}
   overplot/table result-amber0003.tbl :WAVE :VIS2LAM_{stindex}
enddo
! write legend
!SET/GRAP colour=1 ltype=1
!OVERPLOT/LINE 1 245,118,mm 255,118,mm
!SET/GRAP colour=1
!LABEL/GRAPHIC "Baseline 1" 265,118,mm 0 1 0
!SET/GRAP colour=2 ltype=2
!OVERPLOT/LINE 2 245,123,mm 255,123,mm
!SET/GRAP colour=2
!LABEL/GRAPHIC "Baseline 2" 265,123,mm 0 1 0
!SET/GRAP colour=3 ltype=3
!OVERPLOT/LINE 3 245,128,mm 255,128,mm
!SET/GRAP colour=3
!LABEL/GRAPHIC "Baseline 3" 265,128,mm 0 1 0
                                                                                                                                          
                                                                                                                                          
! Averaging spectrum over time and plotting
write/keyword stindex/I/1/1 1
write/out   "Averaging spectrum for baseline {stindex}"
select/tabl result-amber0007.tbl :STA_INDEX.EQ.{sta1}
$$rm -f imghk*.bdf mycat.cat avespec.bdf avespec.tbl
copy/teim           result-amber0007.tbl :FLUX_PI_MORE_PJ P6=imghk
create/icat         mycat.cat imghk*.bdf
average/images      avespec = mycat.cat
copy/it             avespec.bdf avespec.tbl
copy/tt             avespec  #1  result-amber0003.tbl  :SPEC_{stindex}
$$rm -f imghk*.bdf mycat.cat avespec.bdf avespec.tbl

write/keyword stindex/I/1/1 2
write/out   "Averaging spectrum for baseline {stindex}"
select/tabl result-amber0007.tbl :STA_INDEX.EQ.{sta2}
$$rm -f imghk*.bdf mycat.cat avespec.bdf avespec.tbl
copy/teim           result-amber0007.tbl :FLUX_PI_MORE_PJ P6=imghk
create/icat         mycat.cat imghk*.bdf
average/images      avespec = mycat.cat
copy/it             avespec.bdf avespec.tbl
copy/tt             avespec  #1  result-amber0003.tbl  :SPEC_{stindex}
$$rm -f imghk*.bdf mycat.cat avespec.bdf avespec.tbl

write/keyword stindex/I/1/1 3
write/out   "Averaging spectrum for baseline {stindex}"
select/tabl result-amber0007.tbl :STA_INDEX.EQ.{sta3}
$$rm -f imghk*.bdf mycat.cat avespec.bdf avespec.tbl
copy/teim           result-amber0007.tbl :FLUX_PI_MORE_PJ P6=imghk
create/icat         mycat.cat imghk*.bdf
average/images      avespec = mycat.cat
copy/it             avespec.bdf avespec.tbl
copy/tt             avespec  #1  result-amber0003.tbl  :SPEC_{stindex}
$$rm -f imghk*.bdf mycat.cat avespec.bdf avespec.tbl



!get the min and max to plot the 3 spectra on the same plot
write/out "get the max of the spectra"
do stindex = 1 3
statistics/table result-amber0003.tbl :SPEC_{stindex}
enddo
compute/table result-amber0003.tbl :MAX_1 = MAX(:SPEC_0001,:SPEC_0002)
compute/table result-amber0003.tbl :MIN_1 = MIN(:SPEC_0001,:SPEC_0002)
statistics/table result-amber0003.tbl :MAX_1
statistics/table result-amber0003.tbl :MIN_1
compute/table result-amber0003.tbl :MAX_COL = MAX(:MAX_1,:SPEC_0003)
compute/table result-amber0003.tbl :MIN_COL = MIN(:MIN_1,:SPEC_0003)
statistics/table result-amber0003.tbl :MAX_COL
write/keyword Maximumflux/r/1/1 {OUTPUTR(2)}
statistics/table result-amber0003.tbl :MIN_COL
write/keyword Minimumflux/r/1/1 {OUTPUTR(1)}
write/out "read the stats on the table"
                                                                                                                                          
! plot the data on the same plot + create postscript.ps
   write/out   "Plot spectrum for baseline data"
   set/graph pmode=0 font=1 stype=0 ltype=1 colour=1
overplot/axes {Minimumlam(1)},{Maximumlam(1)} {Minimumflux(1)},{Maximumflux(1)},2000,500  -100,-45,170,90 "Wavelength" "Flux count"
SET/GRAP colour=1 ltype=1
   overplot/table result-amber0003.tbl :WAVE :SPEC_0001
do stindex = 2 3
SET/GRAP colour={stindex} ltype={stindex}
   overplot/table result-amber0003.tbl :WAVE :SPEC_{stindex}
enddo

                                                                                                                                          
                                                                                                                                          
!removed for now                                                                                                                                          
! Averaging closure phase over time and plotting
!   write/out   "Averaging spectrum for baseline {stindex}"
!   $$rm -f closghk*.bdf mycat.cat aveclos.bdf aveclos.tbl
!   copy/teim           result-amber0006.tbl :T3PHI P6=closghk
!   create/icat         mycat.cat closghk*.bdf
!   average/images      aveclos = mycat.cat
!   copy/it             aveclos.bdf aveclos.tbl
!   copy/tt             aveclos  #1  result-amber0003.tbl  :CLOSPHASE
!   $$rm -f closghk*.bdf mycat.cat aveclos.bdf aveclos.tbl
!statistics/table result-amber0003.tbl :CLOSPHASE
!write/keyword Maximumcl/r/1/1 {OUTPUTR(2)}
!write/keyword Minimumcl/r/1/1 {OUTPUTR(1)}
!  ! plot the data on the same plot + create postscript.ps
!   write/out   "Plot phase closure for baseline data"
!   set/graph pmode=0 font=1 stype=0 ltype=1 colour=1
!   overplot/axes {Minimumlam(1)},{Maximumlam(1)} {Minimumcl(1)},{Maximumcl(1)} -100,-35,170,15 "Wavelength" "Phase Closure"
!overplot/table result-amber0003.tbl :WAVE :CLOSPHASE

! copy to name according the product number
copy/graph POSTSCRIPT
cmdLine = "cp postscript.ps" // outfile
outputi = m$system(cmdLine)
!$$cp postscript.ps /tmp/amber_plot.ps
                                                                                                                                          
!enddo
ENDIF


!wait
wait/secs 5

enddo



